@@ -21,9 +21,7 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
  */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
+#include "config.h"
 
 #include <string.h>
 
@@ -1115,7 +1113,7 @@ peas_engine_load_plugin_real (PeasEngine     *engine,
           g_set_error (&info->error,
                        PEAS_PLUGIN_INFO_ERROR,
                        PEAS_PLUGIN_INFO_ERROR_DEP_NOT_FOUND,
-                       _("Dependency '%s' was not found"),
+                       _("Dependency “%s” was not found"),
                        dependencies[i]);
           goto error;
         }
@@ -1125,7 +1123,7 @@ peas_engine_load_plugin_real (PeasEngine     *engine,
           g_set_error (&info->error,
                        PEAS_PLUGIN_INFO_ERROR,
                        PEAS_PLUGIN_INFO_ERROR_LOADING_FAILED,
-                       _("Dependency '%s' failed to load"),
+                       _("Dependency “%s” failed to load"),
                        peas_plugin_info_get_name (dep_info));
           goto error;
         }
@@ -1139,7 +1137,7 @@ peas_engine_load_plugin_real (PeasEngine     *engine,
       g_set_error (&info->error,
                    PEAS_PLUGIN_INFO_ERROR,
                    PEAS_PLUGIN_INFO_ERROR_LOADER_NOT_FOUND,
-                   _("Plugin loader '%s' was not found"),
+                   _("Plugin loader “%s” was not found"),
                    peas_utils_get_loader_from_id (info->loader_id));
       goto error;
     }
@@ -1301,6 +1299,7 @@ peas_engine_provides_extension (PeasEngine     *engine,
   return peas_plugin_loader_provides_extension (loader, info, extension_type);
 }
 
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 /**
  * peas_engine_create_extensionv: (rename-to peas_engine_create_extension)
  * @engine: A #PeasEngine.
@@ -1352,6 +1351,7 @@ peas_engine_create_extensionv (PeasEngine     *engine,
 
   return extension;
 }
+G_GNUC_END_IGNORE_DEPRECATIONS
 
 /**
  * peas_engine_create_extension_valist: (skip)
@@ -1381,9 +1381,12 @@ peas_engine_create_extension_valist (PeasEngine     *engine,
                                      const gchar    *first_property,
                                      va_list         var_args)
 {
-  guint n_parameters;
+  G_GNUC_BEGIN_IGNORE_DEPRECATIONS
   GParameter *parameters;
+  G_GNUC_END_IGNORE_DEPRECATIONS
+
   PeasExtension *exten;
+  guint n_parameters;
 
   g_return_val_if_fail (PEAS_IS_ENGINE (engine), NULL);
   g_return_val_if_fail (info != NULL, NULL);
@@ -1632,7 +1635,7 @@ peas_engine_get_default (void)
 }
 
 /* < private >
- * peas_engine_shutdown:
+ * _peas_engine_shutdown:
  *
  * Frees memory shared by PeasEngines.
  * No libpeas API should be called after calling this.
@@ -1640,7 +1643,7 @@ peas_engine_get_default (void)
  * Note: this is private API and as such is not thread-safe.
  */
 void
-peas_engine_shutdown (void)
+_peas_engine_shutdown (void)
 {
   gint i;
 
