@@ -101,6 +101,7 @@ peas_plugin_loader_python_provides_extension (PeasPluginLoader *loader,
   return the_type != G_TYPE_INVALID;
 }
 
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 static PeasExtension *
 peas_plugin_loader_python_create_extension (PeasPluginLoader *loader,
                                             PeasPluginInfo   *info,
@@ -152,6 +153,7 @@ out:
   PyGILState_Release (state);
   return object;
 }
+G_GNUC_END_IGNORE_DEPRECATIONS
 
 static gboolean
 peas_plugin_loader_python_load (PeasPluginLoader *loader,
